@@ -19,7 +19,7 @@
  * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
  * PERFORMANCE OF THIS SOFTWARE.
  */
-/* $XFree86: xc/extras/fontconfig/src/fccharset.c,v 1.2 2003/06/04 16:29:39 dawes Exp $ */
+/* $XFree86: xc/extras/fontconfig/src/fccharset.c,v 1.3 2007/04/09 15:37:10 tsi Exp $ */
 
 #include <stdlib.h>
 #include "fcint.h"
@@ -254,6 +254,7 @@ FcCharSetIterSet (const FcCharSet *fcs, FcCharSetIter *iter)
 	{
 	    iter->ucs4 = ~0;
 	    iter->leaf = 0;
+	    iter->pos = 0;
 	    return;
 	}
         iter->ucs4 = (FcChar32) fcs->numbers[pos] << 8;
