@@ -1,4 +1,4 @@
-/* $XFree86: xc/programs/Xserver/hw/dmx/config/dmxconfig.c,v 1.2 2005/01/30 17:48:44 tsi Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/dmx/config/dmxconfig.c,v 1.5 2007/01/23 18:02:57 tsi Exp $ */
 /*
  * Copyright 2002-2003 Red Hat Inc., Durham, North Carolina.
  *
@@ -46,7 +46,6 @@
 #include "dmxstat.h"
 #include "parser.h"
 
-extern int  yyparse(void);
 extern FILE *yyin;
 
 static char *dmxXkbRules;
@@ -70,7 +69,6 @@ typedef struct DMXConfigCmdStruct {
     DMXConfigList *xinputs;
 } DMXConfigCmd, *DMXConfigCmdPtr;
 
-extern DMXConfigEntryPtr    dmxConfigEntry;
 static DMXConfigCmd  dmxConfigCmd;
 
 static int dmxDisplaysFromCommandLine;
@@ -298,7 +296,7 @@ static void dmxConfigCopyFromOption(DMXConfigOptionPtr o)
 {
     DMXConfigStringPtr pt;
     int                argc   = 0;
-    char               **argv = NULL;
+    char               const **argv = NULL;
 
     if (serverGeneration != 1) return; /* FIXME: only do once, for now */
     if (!o || !o->string) return;
@@ -309,8 +307,9 @@ static void dmxConfigCopyFromOption(DMXConfigOptionPtr o)
             argv[argc] = (char *)pt->string;
         }
     }
-    argv[0] = NULL;
-    ProcessCommandLine(argc+1, argv);
+    argc++;
+    argv[0] = argv[argc] = NULL;
+    ProcessCommandLine(argc, argv);
     free(argv);
 }
 
