@@ -1,6 +1,6 @@
-/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/ati/atichip.c,v 1.37 2003/10/07 22:47:11 martin Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/ati/atichip.c,v 1.44 2008/01/01 00:39:59 tsi Exp $ */
 /*
- * Copyright 1997 through 2003 by Marc Aurele La France (TSI @ UQV), tsi@xfree86.org
+ * Copyright 1997 through 2008 by Marc Aurele La France (TSI @ UQV), tsi@xfree86.org
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided that
@@ -33,9 +33,6 @@
 const char *ATIChipNames[] =
 {
     "Unknown",
-
-#ifndef AVOID_CPIO
-
     "IBM VGA or compatible",
     "ATI 18800",
     "ATI 18800-1",
@@ -51,9 +48,6 @@ const char *ATIChipNames[] =
     "ATI 68800-6",
     "ATI 68800LX",
     "ATI 68800AX",
-
-#endif /* AVOID_CPIO */
-
     "ATI 88800GX-C",
     "ATI 88800GX-D",
     "ATI 88800GX-E",
@@ -102,14 +96,13 @@ const char *ATIChipNames[] =
     "ATI Radeon 9600",
     "ATI Radeon 9800",
     "ATI Radeon 9800XT",
+    "ATI unknown Radeon",
     "ATI Rage HDTV"
 };
 
 const char *ATIFoundryNames[] =
     { "SGS", "NEC", "KCS", "UMC", "TSMC", "5", "6", "UMC" };
 
-#ifndef AVOID_CPIO
-
 /*
  * ATIMach32ChipID --
  *
@@ -152,8 +145,6 @@ ATIMach32ChipID
     }
 }
 
-#endif /* AVOID_CPIO */
-
 /*
  * ATIMach64ChipID --
  *
@@ -442,9 +433,6 @@ ATIChipID
 {
     switch (ChipID)
     {
-
-#ifndef AVOID_CPIO
-
         case OldChipID('A', 'A'):  case NewChipID('A', 'A'):
             return ATI_CHIP_68800_3;
 
@@ -457,8 +445,6 @@ ATIChipID
         case OldChipID('A', 'X'):  case NewChipID('A', 'X'):
             return ATI_CHIP_68800AX;
 
-#endif /* AVOID_CPIO */
-
         case OldChipID('G', 'X'):  case NewChipID('G', 'X'):
             switch (ChipRev)
             {
@@ -738,9 +724,9 @@ ATIChipID
 
         default:
             /*
-             * I'd say it's a Rage128 or a Radeon here, except that I don't
-             * support them.
+             * Treat anything else as an unknown Radeon.  Please keep the above
+             * up-to-date however, as it serves as a central chip list.
              */
-            return ATI_CHIP_Mach64;
+            return ATI_CHIP_Radeon;
     }
 }
