@@ -2,11 +2,7 @@
  * Copyright (C) 1998-2001 VMware, Inc.
  * All Rights Reserved
  * **********************************************************/
-#ifdef VMX86_DEVEL
-char rcsId_vmwarexaa[] =
-    "Id: $";
-#endif
-/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/vmware/vmwarexaa.c,v 1.6 2003/04/13 18:09:27 dawes Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/vmware/vmwarexaa.c,v 1.7 2006/01/09 15:00:15 dawes Exp $ */
 
 #include "vmware.h"
 
