@@ -35,7 +35,7 @@
  * TORTIOUS ACTIONS, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
  * PERFORMANCE OF THIS SOFTWARE.
  */
-/* $XFree86: xc/programs/Xserver/hw/xfree86/input/aiptek/xf86Aiptek.c,v 1.1 2003/06/25 18:06:25 eich Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xfree86/input/aiptek/xf86Aiptek.c,v 1.4 2006/03/16 16:50:25 dawes Exp $ */
 
 /*
  *
@@ -971,15 +971,16 @@ xf86AiptekHIDOpen(LocalDevicePtr local)
     }
 
     ioctl(local->fd, EVIOCGNAME(sizeof(name)), name);
-    ErrorF("%s HID Device name: \"%s\"\n", XCONFIG_PROBED, name);
+    xf86Msg(X_PROBED, "%s: HID Device name: \"%s\"\n", local->name, name);
 
     ioctl(local->fd, EVIOCGVERSION, &version);
-    ErrorF("%s HID Driver Version: %d.%d.%d\n", XCONFIG_PROBED,
+    xf86Msg(X_PROBED, "%s: HID Driver Version: %d.%d.%d\n", local->name,
             version>>16, (version>>8) & 0xff, version & 0xff);
 
-    ErrorF("%s HID Driver knows it has %d devices configured\n", XCONFIG_PROBED,
-            common->numDevices);
-    ErrorF("%s HID Driver is using %d as the fd\n", XCONFIG_PROBED, local->fd);
+    xf86Msg(X_PROBED, "%s: HID Driver knows it has %d devices configured\n",
+	    local->name, common->numDevices);
+    xf86Msg(X_PROBED, "%s: HID Driver is using %d as the fd\n",
+	    local->name, local->fd);
 
     for (i = 0; i < common->numDevices; ++i)
     {
@@ -1681,7 +1682,7 @@ xf86AiptekSwitchMode(ClientPtr client, DeviceIntPtr dev, int mode)
     LocalDevicePtr  local  = (LocalDevicePtr)dev->public.devicePrivate;
     AiptekDevicePtr device = (AiptekDevicePtr)(local->private);
 
-    DBG(3, ErrorF("xf86AiptekSwitchMode() dev=0x%02x mode=%d\n", dev, mode));
+    DBG(3, ErrorF("xf86AiptekSwitchMode() dev=%p mode=%d\n", dev, mode));
 
     switch(mode)
     {
@@ -1699,7 +1700,7 @@ xf86AiptekSwitchMode(ClientPtr client, DeviceIntPtr dev, int mode)
 
         default:
         {
-            DBG(1, ErrorF("xf86AiptekSwitchMode dev=0x%02x invalid mode=%d\n",
+            DBG(1, ErrorF("xf86AiptekSwitchMode dev=%p invalid mode=%d\n",
                    dev, mode));
             return BadMatch;
         }
@@ -2370,11 +2371,7 @@ xf86AiptekInit(InputDriverPtr    drv,
                         dev->identifier);
                 break;
         }
-        if (xf86Verbose)
-        {
-            xf86Msg(X_CONFIG, "%s: BaudRate %u\n", dev->identifier,
-                    val);
-        }
+        xf86Msg(X_CONFIG, "%s: BaudRate %u\n", dev->identifier, val);
     }
     xf86Msg(X_CONFIG, "%s: xf86AiptekInit() finished\n", dev->identifier);
 
@@ -2419,7 +2416,7 @@ xf86AiptekUnplug(pointer p)
  * called when the module subsection is found in XF86Config
  */
 static pointer
-xf86AiptekPlug(pointer    module,
+xf86AiptekPlug(ModuleDescPtr    module,
                pointer    options,
                int*       errmaj,
                int*       errmin)
